==> 0.4.0.zip: gvacommon/setup.py <==
#
# gvacommon - common parts of gnuviechadmin
# Copyright (C) 2016-2018  Jan Dittberner
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
from setuptools import setup, find_packages

from gvacommon import __version__ as version

with open('README.rst') as readme_file:
    readme = readme_file.read()

readme += """
license
-------
"""

with open('COPYING') as license_file:
    readme += license_file.read()

setup(
    name='gvacommon',
    version=version,
    description='common utility code for gnuviechadmin applications',
    long_description=readme,
    classifiers=[
        'Development Status :: 4 - Beta',
        'License :: OSI Approved :: GNU Affero General Public License v3 or later (AGPLv3+)',
        'Programming Language :: Python',
        'Intended Audience :: Developers',
    ],
    keywords='gnuviechadmin',
    url='https://dev.gnuviech-server.de/gvacommon/',
    author='Jan Dittberner',
    author_email='jan@dittberner.info',
    license='AGPLv3+',
    packages=find_packages(),
    test_suite='gvacommon.tests',
    install_requires=[
        'Django',
    ],
    include_package_data=True,
    zip_safe=False
)

==> 0.5.0.zip: gvacommon/setup.py <==
#
# gvacommon - common parts of gnuviechadmin
# Copyright (C) 2016-2020  Jan Dittberner
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
from setuptools import setup, find_packages

from gvacommon import __version__ as version

with open('README.rst') as readme_file:
    readme = readme_file.read()

readme += """
license
-------
"""

with open('COPYING') as license_file:
    readme += license_file.read()

setup(
    name='gvacommon',
    version=version,
    description='common utility code for gnuviechadmin applications',
    long_description=readme,
    classifiers=[
        'Development Status :: 4 - Beta',
        'License :: OSI Approved :: GNU Affero General Public License v3 or later (AGPLv3+)',
        'Programming Language :: Python 3',
        'Programming Language :: Python 3.7',
        'Intended Audience :: Developers',
    ],
    keywords='gnuviechadmin',
    url='https://git.dittberner.info/gnuviech/gvacommon/',
    author='Jan Dittberner',
    author_email='jan@dittberner.info',
    license='AGPLv3+',
    packages=find_packages(),
    test_suite='gvacommon.tests',
    install_requires=[
        'Django',
    ],
    include_package_data=True,
    zip_safe=False
)
